## Final Project

####About vertical farming
Vertical farming is the practice of food production that takes the form of vertically stacked layers and vertically inclined surfaces. The method is executed inside a controlled environment building, usually without soil or natural light.

Also known as indoor farming, vertical farming has in recent years gained recognition as a solid method of sustainability. The system was born out of the challenges affecting the 21st century, specifically issues like food shortage, resource depletion, and overpopulation.
Controlled Environment Agriculture (CEA) is an advanced and intensive form of hydroponically-based agriculture where plants grow within a controlled environment to optimize horticultural practices.environmental conditions can be easily regulated to encourage the growth of plants

Benefits:
1. grow more than one type of plant simultaneously without taking up much space
2. 95% less water than conventional horizontal farming (ref: stat)
3. More crops in the same times (when done at scale)
4. controlled environment - not season dependant
5. Reduced distance between food production and consumption
6. Closer to self-sustainability if system done correctly

Cons:
1. Energy consumption is high
2. Specialised equipment
3. Natural pollination not possible in a controlled environment
4. Technology dependancy

While to make a viable business around vertical farming has many aspects like space optimisation, demand and supply rate, etc., in this project I want to concentrate on the technical aspects and make them modifiable when scaled to make a bigger farm.
Decisions to make successful growing:
1. Crop selection  
2. Lighting selection
3. Data, sensors, control and software
4. Substrate selection
5. Spacing of crops
6. Temperature and humidity

####PLAN:
* CAD - make 2D for cutting/production  files & make a 3D model, animate and render  
* Inputs -  sensors to measure
* Output -  LED  
* CAM - lasercut parts, use vinyl cutter for
* 3D printing - joints, make casing
* Electronic design, production and embedded programming - To make the micro-contoller PCB  
* Network and Communication - Add WiFi module to control it remotely?  
* Interface and Application programming - To make a GUI (phone app?)  

![Spiral Development Plan](./images/final-project/spiral.jpg)

#### Process
* First I started by making a CAD model in Rhino. I explored multiple forms.
![forms](./images/final-project/forms.jpg)
Since I need to make as many parts as possible in the lab instead of buying parts, I modify the design to make it simpler.
![](./images/final-project/CADv1.png)
![](./images/final-project/v0.jpg)

#### Designing the electronics:

I listed out the inputs and outputs to include in the design after studying some similar projects like [POWAR](http://www.pablozuloaga.com/POWAR.html), [Mixoponics](https://fab.academany.org/2020/labs/bahrain/students/muhja-aljaser/projects/final-project/), etc.

####Inputs to include:  
  1. DHT11 - temperature and humidity sensor  
  2. Phototransistor - to measure ambient light intensity  
  3. Potentiometer / variable resistance - to control flow of water through pump  
  4. Potentiometer / variable resistance - to control grow light intensity   

####Outputs are:  
  1. 12V DC pump to pump water through a sprinkler system  
  2. 12V DC growth light strip with 3:1 RB 5050SMD LEDs  
  3. SSD1306 OLED screen with I2C  

With the help my instructor Steven, I developed a basic scheme for the electronics.
![scheme](./images/final-project/scheme.jpg)

Also counting the pins required for each sensor and actuator:
![pins](./images/final-project/pins.png)

Since I am not in the lab, I need to order some components myself. I start making a Bill of Materials for the project electronics:
![bom](./images/final-project/bom.jpg)

Next, I started making a schematic according to the sketch, connecting each component to V, GND and respective pins.

12V DC-DC converter to 5V
The DC-DC converter will have connections based on the datasheet...
I'm connecting a toggle switch to the converter, which will be the power on/off switch for the user
I'm also adding a red SMD LED as a power indicator.
![](./images/final-project/dc-dc.png)
![](./images/final-project/power-led.png)


Phototransistor has two options of circuits, according to [this guide](http://hades.mech.northwestern.edu/index.php/Photodiodes_and_Phototransistors).
![Photodiodes_and_Phototransistors](./images/final-project/pt.jpg)

I use the Phototransistor in active mode - meaning the output of the transistor is proportional to the intensity of the light.
![pt](./images/final-project/phototransistor.png)

The potentiometers have 3 pins - one for power, one GND and third data that connects to the MCU.
![](./images/final-project/2pots.png)

The temperature and humidity sensor DHT11 has 3 pins - 5V power, GND and data which connects to a digital pin of the MCU.
Ref: [Introduction to DHT11](https://www.theengineeringprojects.com/2019/03/introduction-to-dht11.html)
![](./images/final-project/dht11.png)

I need to read more about which display to choose - for now I'm adding a 16x2 character LCD with I2C to make serial communication easier and use less pins on the MCU, only SDA and SCL.
![](./images/final-project/lcd.png)

A 12V DC water pump is connected to the MCU with a n-channel MOSFET so I can control the flow of water using Pulse Width Modulation.
![](./images/final-project/mosfet-pump.png)

A 12V DC LED growlight strip is connected to the MCU with a n-channel MOSFET so I can control the light intensity. These come in different ratios of red-blue lights. I use one with 3:1 meant for leafy plants.  
![](./images/final-project/mosfet-led.png)  

Next, I use KiCAD to put all the schematics together and begin to design my PCB.  
![schematic v1](./images/final-project/schematic.png)

While making the schematic I realise not all sensors and actuators need to be on the PCB itself, some like the pump and the led and the DHT11 need to be at a different physical location on the designed box, so I need to add header pins and connect them using wires later.
To clarify this, I begin modifying my 3D CAD model on Rhino.

![schematic v5](./images/final-project/farming.v5.schematic.jpg)

[traces](./images/final-project/farming.v6-traces.png)
[outline](./images/final-project/farming.v6-outline.png)

milling prcoess
soldering Components
Testing board
Connecting all inputs and outputs

Programming:
I will use the FabISP I made in Electronics Production week as a programmer to program my farming board with all the inputs and outputs.

[AVRDUDE](http://www.nongnu.org/avrdude/) is a utility to download/upload/manipulate the ROM and EEPROM contents of AVR microcontrollers using the in-system programming technique (ISP).

1. Connect the new board with a ribbon cable to the FabISP programmer through a compatible USB adaptor.
![](cobnnection)
Check the orientation of the cables is on correct order. VCC of the FabISP matches the VCC of the target board(mine with ATtiny44)
Check System Report > Hardware> USB, should detect the USBtinyISP.
Next in a terminal window,
<code>avrdude -c usbtiny -p t44</code>
It should show that the device is initialized and show a signature.
![](./images/final-project/avrdude.initialize.jpg)

Next, I will start adding the i/o one by one starting with the OLED so I can use it as a display for troubleshooting along the way. Since I'm using a Attiny44 with 4k memory, I will use the minimal versions of OLED and DHT libraries to make enough space for the rest of the components.

1. Install OLED library from https://github.com/datacute/Tiny4kOLED which is a Library for an ATTiny85 to use an SSD1306 powered, double buffered, 128x32 pixel OLED, over I2C.

Open Arduino IDE, in Tools > Board Manager, add the https://github.com/technoblogy/tiny-i2c in additional boards URLs.

Sketch > Include Library > Manage Librarries, select Tiny4kOLED and install.
![](./images/final-project/tiny4koled.library.jpg)
















### 3D printing
Knobs for potentiometers:
[3D model]
<div class="sketchfab-embed-wrapper"> <iframe title="Knob" frameborder="0" allowfullscreen mozallowfullscreen="true" webkitallowfullscreen="true" allow="fullscreen; autoplay; vr" xr-spatial-tracking execution-while-out-of-viewport execution-while-not-rendered web-share src="https://sketchfab.com/models/84d5f9911fdd4ada838a230d931926ee/embed?ui_theme=dark"> </iframe> <p style="font-size: 13px; font-weight: normal; margin: 5px; color: #4A4A4A;"> <a href="https://sketchfab.com/3d-models/knob-84d5f9911fdd4ada838a230d931926ee?utm_medium=embed&utm_campaign=share-popup&utm_content=84d5f9911fdd4ada838a230d931926ee" target="_blank" style="font-weight: bold; color: #1CAAD9;"> Knob </a> by <a href="https://sketchfab.com/emaitee?utm_medium=embed&utm_campaign=share-popup&utm_content=84d5f9911fdd4ada838a230d931926ee" target="_blank" style="font-weight: bold; color: #1CAAD9;"> emaitee </a> on <a href="https://sketchfab.com?utm_medium=embed&utm_campaign=share-popup&utm_content=84d5f9911fdd4ada838a230d931926ee" target="_blank" style="font-weight: bold; color: #1CAAD9;">Sketchfab</a></p>
</div>

### [Gcode file](./images/final-project/knob.v3.gcode) has these settings:
Wall Thickness
speed
Brim

### Lasercutting






KICAD symbol and footprint guide:
https://app.ultralibrarian.com/content/help/index.htm?converting-ultra-librarian-dow.htm









* What does it do?
* Who's done what beforehand?
* What did you design?
* What materials and components were used?
* Where did they come from?
* How much did they cost?
* What parts and systems were made?
* What processes were used?
* What questions were answered?
* What worked? What didn't?
* How was it evaluated?
* What are the implications?

####References
Controlled Environment Agriculture (CEA): https://cea.cals.cornell.edu/about-cea/  
Basics of homegrown vertical farms:
https://www.diys.com/vertical-farming/  
https://ecowarriorprincess.net/2017/11/a-beginners-guide-to-vertical-farming/  
Aquapioneers: business integrating product and services for aquaponic farming http://aquapioneers.io/  
Modular Vertical Farming projects:
https://hackaday.io/project/5084-modular-vertical-farming  
https://moltkegarden.com/  
Lighting:
https://www.lighting.philips.com/main/products/horticulture/hortiblog/vertical-farming/how-to-build-a-successful-vertical-farm  
True garden:
https://truegarden.com/residential/  
http://www.conceptualdevices.com/2015/03/farm-x-the-first-modular-vertical-farm-concept-unveiled-almost/  
 FARM-X. The First Modular Vertical Farm Concept (Almost) Unveiled :   
https://create.arduino.cc/projecthub/dymonxd/diy-grow-led-light-designing-a-better-sun-1adec1

 </p><br /><br /><br /><br /><br /><br /><br /><br />
<p><br><br><a href=”https://skunkology.com/how-does-hydroponics-work-infographics/” target=”_blank”><img src=”https://skunkology.com/wp-content/uploads/2017/10/How-does-hydroponics-work.jpg” alt=”How does hydroponics work? – Infographics” border=”0″ width=”550″ /></a><br><span style=”font-size: 14px;”>(via <a href=”https://www.skunkology.com/”>Skunkology.com</a>).</span><br><br><br></p><br /><br /><br /><br /><br /><br /><br /><br />
<p>


Weather station : https://create.arduino.cc/projecthub/herolivechannel/weather-station-arduino-dht11-sensor-oled-display-2f8e50
DHT11 and OLED display
